==> lxqt-l10n-0.11.0.tar.xz: lxqt-l10n-0.11.0/lxqt-globalkeys/lxqt-config-globalkeyshortcuts/lxqt-config-globalkeyshortcuts_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>CommandFinder</name>
    <message>
        <source>...</source>
        <translation type="vanished">...</translation>
    </message>
    <message>
        <source>Find a command</source>
        <translation type="vanished">Encontrar um comando</translation>
    </message>
</context>
<context>
    <name>DefaultModel</name>
    <message>
        <location filename="../../../default_model.cpp" line="49"/>
        <source>Command</source>
        <translation type="unfinished">Comando</translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="50"/>
        <source>DBus call</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="51"/>
        <source>Client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="141"/>
        <source>Id</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="144"/>
        <source>Shortcut</source>
        <translation type="unfinished">Atalho</translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="147"/>
        <source>Description</source>
        <translation type="unfinished">Descrição</translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="150"/>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="153"/>
        <source>Info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditActionDialog</name>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="14"/>
        <source>Edit Action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="31"/>
        <source>&amp;Shortcut:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="74"/>
        <source>&amp;Description:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="87"/>
        <source>&amp;Enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="102"/>
        <source>&amp;Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="109"/>
        <source>&amp;DBus message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="118"/>
        <source>Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="164"/>
        <source>Co&amp;mmand:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="206"/>
        <source>S&amp;ervice:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="219"/>
        <source>&amp;Path:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="232"/>
        <source>&amp;Interface:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="245"/>
        <source>&amp;Method:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../../main_window.ui" line="14"/>
        <source>Global Actions Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="52"/>
        <source>Add ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="62"/>
        <source>Remove</source>
        <translation type="unfinished">Remover</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="72"/>
        <source>Modify ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="89"/>
        <source>Swap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="115"/>
        <source>Multiple actions behaviour:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="123"/>
        <source>First</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="128"/>
        <source>Last</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="133"/>
        <source>None</source>
        <translation type="unfinished">Nada</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="138"/>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="176"/>
        <source>Close</source>
        <translation type="unfinished">Fechar</translation>
    </message>
</context>
<context>
    <name>ShortcutConfigWindow</name>
    <message>
        <source>LXQt Shortcut Editor</source>
        <translation type="vanished">Editor de atalhos do LXQt</translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="vanished">Descrição</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation type="vanished">Atalho</translation>
    </message>
    <message>
        <source>Command</source>
        <translation type="vanished">Comando</translation>
    </message>
    <message>
        <source>Add New</source>
        <translation type="vanished">Adicionar</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="vanished">Remover</translation>
    </message>
    <message>
        <source>Add Group</source>
        <translation type="vanished">Adicionar grupo</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation type="vanished">Restaurar</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Fechar</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>None</source>
        <translation type="vanished">Nada</translation>
    </message>
    <message>
        <source>Add Shortcut</source>
        <translation type="vanished">Adicionar atalho</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="vanished">Remover</translation>
    </message>
    <message>
        <source>New Group</source>
        <translation type="vanished">Novo grupo</translation>
    </message>
    <message>
        <source>Reset Changes</source>
        <translation type="vanished">Restaurar alterações</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-globalkeys/lxqt-config-globalkeyshortcuts/lxqt-config-globalkeyshortcuts_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>CommandFinder</name>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Find a command</source>
        <translation>Localizar um comando</translation>
    </message>
</context>
<context>
    <name>DefaultModel</name>
    <message>
        <location filename="../../../default_model.cpp" line="49"/>
        <source>Command</source>
        <translation>Comando</translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="50"/>
        <source>DBus call</source>
        <translation>Chamada DBus</translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="51"/>
        <source>Client</source>
        <translation>Cliente</translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="141"/>
        <source>Id</source>
        <translation>ID</translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="144"/>
        <source>Shortcut</source>
        <translation>Atalho</translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="147"/>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="150"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="153"/>
        <source>Info</source>
        <translation>Informação</translation>
    </message>
</context>
<context>
    <name>EditActionDialog</name>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="14"/>
        <source>Edit Action</source>
        <translation>Editar ação</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="31"/>
        <source>&amp;Shortcut:</source>
        <translation>Atal&amp;ho:</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="74"/>
        <source>&amp;Description:</source>
        <translation>&amp;Descrição:</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="87"/>
        <source>&amp;Enabled</source>
        <translation>&amp;Ativado</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="102"/>
        <source>&amp;Command</source>
        <translation>&amp;Comando</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="109"/>
        <source>&amp;DBus message</source>
        <translation>Mensagem &amp;DBus</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="118"/>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="164"/>
        <source>Co&amp;mmand:</source>
        <translation>Co&amp;mando:</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="206"/>
        <source>S&amp;ervice:</source>
        <translation>S&amp;erviço:</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="219"/>
        <source>&amp;Path:</source>
        <translation>Cami&amp;nho:</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="232"/>
        <source>&amp;Interface:</source>
        <translation>&amp;Interface:</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="245"/>
        <source>&amp;Method:</source>
        <translation>&amp;Método:</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../../main_window.ui" line="14"/>
        <source>Global Actions Manager</source>
        <translation>Gestor de ações globais</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="52"/>
        <source>Add ...</source>
        <translation>Adicionar...</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="62"/>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="72"/>
        <source>Modify ...</source>
        <translation>Modificar...</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="89"/>
        <source>Swap</source>
        <translation>Trocar</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="115"/>
        <source>Multiple actions behaviour:</source>
        <translation>Comportamento de ações múltiplas:</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="123"/>
        <source>First</source>
        <translation>Primeira</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="128"/>
        <source>Last</source>
        <translation>Última</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="133"/>
        <source>None</source>
        <translation>Nenhuma</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="138"/>
        <source>All</source>
        <translation>Todas</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="176"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
</context>
<context>
    <name>ShortcutConfigWindow</name>
    <message>
        <source>LXQt Shortcut Editor</source>
        <translation>Editor de atalhos do LXQt</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Atalho</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Comando</translation>
    </message>
    <message>
        <source>Add New</source>
        <translation>Adicionar</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
    <message>
        <source>Add Group</source>
        <translation>Adicionar grupo</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Restaurar</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <source>Add Shortcut</source>
        <translation>Adicionar atalho</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
    <message>
        <source>New Group</source>
        <translation>Novo grupo</translation>
    </message>
    <message>
        <source>Reset Changes</source>
        <translation>Restaurar alterações</translation>
    </message>
</context>
</TS>
